;; Generated package description from org-contacts.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "org-contacts" "1.3.0.20260829.10" "Contacts management system for Org mode" '((emacs "29.1") (org "9.7")) :commit "886d78099e4cf5ed620379b81097134fea4b8e83" :authors '(("Julien Danjou" . "julien@danjou.info")) :maintainer '("stardiviner" . "numbchild@gmail.com") :keywords '("contacts" "org-mode" "outlines" "hypermedia" "calendar") :url "https://repo.or.cz/org-contacts.git")
